pub struct FileLogReader<C: RaftTypeConfig> { /* private fields */ }Trait Implementations
Sourceimpl<C: Clone + RaftTypeConfig> Clone for FileLogReader<C>
impl<C: Clone + RaftTypeConfig> Clone for FileLogReader<C>
Sourcefn clone(&self) -> FileLogReader<C>
fn clone(&self) -> FileLogReader<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C> RaftLogReader<C> for FileLogReader<C>
impl<C> RaftLogReader<C> for FileLogReader<C>
Sourceasync fn try_get_log_entries<RB: RangeBounds<u64> + Clone + Debug + OptionalSend>(
&mut self,
range: RB,
) -> Result<Vec<C::Entry>, Error>
async fn try_get_log_entries<RB: RangeBounds<u64> + Clone + Debug + OptionalSend>( &mut self, range: RB, ) -> Result<Vec<C::Entry>, Error>
Get a series of log entries from storage. Read more
Sourceasync fn read_vote(&mut self) -> Result<Option<C::Vote>, Error>
async fn read_vote(&mut self) -> Result<Option<C::Vote>, Error>
Return the last saved vote by
RaftLogStorage::save_vote. Read moreSourcefn leader_bounded_stream<RB>(
&mut self,
leader: <C as RaftTypeConfig>::LeaderId,
range: RB,
) -> impl Future<Output = impl Stream<Item = Result<<C as RaftTypeConfig>::Entry, LeaderBoundedStreamError<C>>> + OptionalSend> + Send
fn leader_bounded_stream<RB>( &mut self, leader: <C as RaftTypeConfig>::LeaderId, range: RB, ) -> impl Future<Output = impl Stream<Item = Result<<C as RaftTypeConfig>::Entry, LeaderBoundedStreamError<C>>> + OptionalSend> + Send
Read log entries as a stream, conditional on vote state. Read more
Sourcefn entries_stream<RB>(
&mut self,
range: RB,
) -> impl Future<Output = impl Stream<Item = Result<<C as RaftTypeConfig>::Entry, Error>> + OptionalSend> + Send
fn entries_stream<RB>( &mut self, range: RB, ) -> impl Future<Output = impl Stream<Item = Result<<C as RaftTypeConfig>::Entry, Error>> + OptionalSend> + Send
Read log entries as a stream without leader validation. Read more