HpcStateMachine

Struct HpcStateMachine 

pub struct HpcStateMachine<C, S>
where C: RaftTypeConfig<SnapshotData = Cursor<Vec<u8>>>, S: StateMachineState<C>,
{ /* private fields */ }
The generic Raft state machine wrapping an application state.

Implementations

Source

impl<C, S> HpcStateMachine<C, S>

pub fn new(state: Arc<RwLock<S>>) -> Self

pub fn with_snapshot_dir( state: Arc<RwLock<S>>, snapshot_dir: PathBuf, ) -> Result<Self>

Create a state machine with persistent snapshot directory.

On startup, loads the latest snapshot from disk if available.

pub fn state(&self) -> Arc<RwLock<S>>

Get a read handle to the application state (for queries).